Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS IQ Permissions.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS IQ Permissions - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for AWS IQ Permissions

AWS IQ Permissions (service prefix: `iq-permission` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

Topics

- Actions Defined by AWS IQ Permissions
- Resource Types Defined by AWS IQ Permissions
- Condition Keys for AWS IQ Permissions

## Actions Defined by AWS IQ Permissions

AWS IQ Permissions has no API operations that can be used in the `Actions` element of an IAM policy statement. To allow access to AWS IQ Permissions, specify `“Action”: “iq-permission:*”` in your policy.

## Resource Types Defined by AWS IQ Permissions

AWS IQ Permissions does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS IQ Permissions, specify `“Resource”: “*”` in your policy.

## Condition Keys for AWS IQ Permissions

IQ Permission has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference .